/*
 * drv_slave_iic.h
 *
 *  Created on: 2025��4��2��
 *      Author: 22332
 */

#ifndef DRV_SLAVE_IIC_H_
#define DRV_SLAVE_IIC_H_
#include "sdk_project_config.h"

extern void bsp_drv_slave_iic_init(void);
extern void bsp_drv_slave_iic_Deinit(void);
extern void bsp_drv_slave_iic_read(uint8_t *pBuf,int len);
extern void bsp_drv_slave_iic_write(const uint8_t *pBuf,int len);
extern void bsp_drv_slave_iic_cfg(uint8_t *pRxBuf,int *iRxLength);
extern void bsp_drv_slave_iic_ctrl_task(void *task);
extern void bsp_drv_slave_iic_ctrl_buf(void *task);

#endif /* DRV_SLAVE_IIC_H_ */
